@@ -20,6 +20,20 @@ use stretch::{style::*, node::{Node, Stretch}, geometry::Size, geometry::Rect};
 
 use crate::actor::image::GenericImage;
 
+#[repr(i32)]
+#[derive(Copy, Clone, Debug, PartialEq)]
+pub enum Key {
+  Space = 32,
+  Enter = 36,
+  Tab = 48,
+  Backspace = 51,
+  Escape = 53,
+  Right = 262,
+  Left = 263,
+  Down = 264,
+  Up = 265
+}
+
 #[derive(Copy, Clone, Debug)]
 pub enum EasingFunction {
     EaseIn,
@@ -103,7 +117,7 @@ pub struct Actor<'a> {
   rotation_animation_to_value: i32,
   rotation_animation_ease: EasingFunction,
 
-  event_handelr: Option<Box<dyn EventHandler + 'a>>,
+  event_handler: Option<Box<dyn EventHandler + 'a>>,
   layout: Option<Box<dyn Layout + 'a>>,
   focused_sub_actor: usize,
   focused: bool,
@@ -113,9 +127,9 @@ pub struct Actor<'a> {
 }
 
 pub trait EventHandler {
-  fn key_focus_in(&mut self, val: u32, actor: &mut Actor);
-  fn key_focus_out(&mut self, val: u32, actor: &mut Actor);
-  fn key_down(&mut self, key: usize, actor: &mut Actor);
+  fn key_focus_in(&mut self, actor: &mut Actor);
+  fn key_focus_out(&mut self, actor: &mut Actor);
+  fn key_down(&mut self, key: Key, actor: &mut Actor);
 }
 
 pub trait Layout {
@@ -169,7 +183,7 @@ impl<'a> Actor<'a> {
       rotation_animation_from_value: 0,
       rotation_animation_to_value: 0,
       rotation_animation_ease: EasingFunction::Linear,
-      event_handelr: event_handler,
+      event_handler: event_handler,
       layout: None,
       focused_sub_actor: 0,
       focused: false,
@@ -444,7 +458,7 @@ impl<'a> Actor<'a> {
     if self.sub_actor_list.len() <= 0 {
         return;
     }
-    // ne more previus actor.
+    // ne more previous actor.
     if self.focused_sub_actor == 0 {
       return;
     }
@@ -456,27 +470,27 @@ impl<'a> Actor<'a> {
 
   pub fn set_focus(&mut self, focused: bool) {
     self.focused = focused;
-    if let Some(mut event_handler) = self.event_handelr.take() {
+    if let Some(mut event_handler) = self.event_handler.take() {
       //println!("set_focus {} {} ", self.name, focused);
   
       if self.focused {
-        event_handler.key_focus_in(1, self);
+        event_handler.key_focus_in(self);
       } else {
-        event_handler.key_focus_out(1, self);
+        event_handler.key_focus_out(self);
       }
-      self.event_handelr = Some(event_handler);
+      self.event_handler = Some(event_handler);
     }
   }
 
-  pub fn handle_input(&mut self, key: usize) {
+  pub fn handle_input(&mut self, key: Key) {
     for sub_actor in self.sub_actor_list.iter_mut() {
       if sub_actor.focused {
         sub_actor.handle_input(key);
       }
     }
-    if let Some(mut event_handler) = self.event_handelr.take() {
+    if let Some(mut event_handler) = self.event_handler.take() {
       event_handler.key_down(key, self);
-      self.event_handelr = Some(event_handler);
+      self.event_handler = Some(event_handler);
     }
   }
 
@@ -542,10 +556,12 @@ impl<'a> Actor<'a> {
   pub fn render(&self, shader_program: GLuint, stretch: &mut Option<Stretch>, actor: Option<&Actor>) {
     let mut x = self.x;
     let mut y = self.y;
+    let mut rotation = self.rotation;
 
     if let Some(main_actor) = actor {
       x += main_actor.x;
       y += main_actor.y;
+      rotation += main_actor.rotation;
     }
 
     //println!("render: {}: x,y = {}, {}", self.name, x, y);
@@ -567,8 +583,8 @@ impl<'a> Actor<'a> {
         Matrix4::<f32>::from_translation(Vector3::new(self.width as f32 * self.anchor_x,
         self.height as f32 * self.anchor_y, 0.0));
 
-    if self.rotation != 0 {
-      transform = transform * Matrix4::<f32>::from_angle_z(Deg(self.rotation as f32));
+    if rotation != 0 {
+      transform = transform * Matrix4::<f32>::from_angle_z(Deg(rotation as f32));
     }
 
     transform = transform * Matrix4::from_nonuniform_scale(self.scale_x,
